@@ -61,6 +61,7 @@ static struct handshake_state *test_handshake_state_new(uint32_t ifindex)
 
 	ths->super.ifindex = ifindex;
 	ths->super.free = test_handshake_state_free;
+	ths->super.refcount = 1;
 
 	return &ths->super;
 }
@@ -2005,7 +2006,6 @@ static void wsc_test_pbc_handshake(const void *data)
 	struct verify_data verify;
 	struct handshake_state *hs;
 	struct eapol_sm *sm;
-	char *hex;
 	struct l_settings *settings;
 
 	eap_init();
@@ -2037,16 +2037,11 @@ static void wsc_test_pbc_handshake(const void *data)
 					"0-00000000-0");
 	l_settings_set_string(settings, "WSC", "EnrolleeMAC",
 					util_address_to_string(sta_address));
-
-	hex = l_util_hexstring(m1_data_2.expected.enrollee_nonce, 16);
-	l_settings_set_string(settings, "WSC", "EnrolleeNonce", hex);
-	l_free(hex);
-
-	hex = l_util_hexstring(m1_data_2.private_key,
-						m1_data_2.private_key_size);
-	l_settings_set_string(settings, "WSC", "PrivateKey", hex);
-	l_free(hex);
-
+	l_settings_set_bytes(settings, "WSC", "EnrolleeNonce",
+				m1_data_2.expected.enrollee_nonce, 16);
+	l_settings_set_bytes(settings, "WSC", "PrivateKey",
+				m1_data_2.private_key,
+				m1_data_2.private_key_size);
 	l_settings_set_string(settings, "WSC", "E-SNonce1",
 					"fdbb480ee6f572f3591cc3b364f2185b");
 	l_settings_set_string(settings, "WSC", "E-SNonce2",
@@ -2099,7 +2094,7 @@ static void wsc_test_pbc_handshake(const void *data)
 					eap_fail, sizeof(eap_fail), false);
 	assert(verify.eapol_failed);
 
-	handshake_state_free(hs);
+	handshake_state_unref(hs);
 	eapol_exit();
 	eap_exit();
 }
@@ -2111,7 +2106,6 @@ static void wsc_test_retransmission_no_fragmentation(const void *data)
 	struct verify_data verify;
 	struct handshake_state *hs;
 	struct eapol_sm *sm;
-	char *hex;
 	struct l_settings *settings;
 
 	eap_init();
@@ -2143,16 +2137,11 @@ static void wsc_test_retransmission_no_fragmentation(const void *data)
 					"0-00000000-0");
 	l_settings_set_string(settings, "WSC", "EnrolleeMAC",
 					util_address_to_string(sta_address));
-
-	hex = l_util_hexstring(m1_data_2.expected.enrollee_nonce, 16);
-	l_settings_set_string(settings, "WSC", "EnrolleeNonce", hex);
-	l_free(hex);
-
-	hex = l_util_hexstring(m1_data_2.private_key,
-						m1_data_2.private_key_size);
-	l_settings_set_string(settings, "WSC", "PrivateKey", hex);
-	l_free(hex);
-
+	l_settings_set_bytes(settings, "WSC", "EnrolleeNonce",
+				m1_data_2.expected.enrollee_nonce, 16);
+	l_settings_set_bytes(settings, "WSC", "PrivateKey",
+				m1_data_2.private_key,
+				m1_data_2.private_key_size);
 	l_settings_set_string(settings, "WSC", "E-SNonce1",
 					"fdbb480ee6f572f3591cc3b364f2185b");
 	l_settings_set_string(settings, "WSC", "E-SNonce2",
@@ -2228,7 +2217,7 @@ static void wsc_test_retransmission_no_fragmentation(const void *data)
 						sizeof(eap_fail), false);
 	assert(verify.eapol_failed);
 
-	handshake_state_free(hs);
+	handshake_state_unref(hs);
 	eapol_exit();
 	eap_exit();
 }
@@ -2331,12 +2320,6 @@ static void test_ap_sta_run(struct test_ap_sta_data *s)
 					s->to_sta_data, len, false);
 	}
 
-	if (s->ap_sm)
-		eapol_sm_free(s->ap_sm);
-
-	if (s->sta_sm)
-		eapol_sm_free(s->sta_sm);
-
 	eapol_exit();
 	eap_exit();
 }
@@ -2353,6 +2336,7 @@ static struct handshake_state *test_ap_sta_hs_new(struct test_ap_sta_data *s,
 
 	ths->super.ifindex = ifindex;
 	ths->super.free = (void (*)(struct handshake_state *s)) l_free;
+	ths->super.refcount = 1;
 	ths->s = s;
 
 	return &ths->super;
@@ -2363,7 +2347,7 @@ static bool random_nonce(uint8_t nonce[])
 	return l_getrandom(nonce, 32);
 }
 
-static void test_ap_sta_install_tk(struct handshake_state *hs,
+static void test_ap_sta_install_tk(struct handshake_state *hs, uint8_t key_idx,
 					const uint8_t *tk, uint32_t cipher)
 {
 	assert(false);
@@ -2479,11 +2463,9 @@ static void wsc_r_test_pbc_handshake(const void *data)
 		.expected_creds = *expected_creds,
 	};
 	uint8_t uuid_e[16];
-	L_AUTO_FREE_VAR(char *, uuid_e_str) = NULL;
 	char ssid_str[33];
 
 	wsc_uuid_from_addr(s.sta_address, uuid_e);
-	uuid_e_str = l_util_hexstring(uuid_e, 16);
 
 	memcpy(wsc_data.expected_creds.addr, s.sta_address, 6);
 	memset(wsc_data.expected_creds.ssid + expected_creds->ssid_len, 0,
@@ -2500,7 +2482,7 @@ static void wsc_r_test_pbc_handshake(const void *data)
 					strlen(ap_8021x_str));
 	l_settings_set_string(ap_8021x_settings, "WSC", "EnrolleeMAC",
 				util_address_to_string(s.sta_address));
-	l_settings_set_string(ap_8021x_settings, "WSC", "UUID-E", uuid_e_str);
+	l_settings_set_bytes(ap_8021x_settings, "WSC", "UUID-E", uuid_e, 16);
 
 	if (expected_creds->auth_type == WSC_AUTHENTICATION_TYPE_WPA2_PERSONAL) {
 		l_settings_set_string(ap_8021x_settings, "WSC",
@@ -2555,8 +2537,8 @@ static void wsc_r_test_pbc_handshake(const void *data)
 
 	test_ap_sta_run(&s);
 
-	handshake_state_free(s.ap_hs);
-	handshake_state_free(s.sta_hs);
+	handshake_state_unref(s.ap_hs);
+	handshake_state_unref(s.sta_hs);
 	__handshake_set_install_tk_func(NULL);
 	l_settings_free(ap_8021x_settings);
 	l_settings_free(sta_8021x_settings);
